// used by casper to replace 
//  /usr/share/plasma/shells/org.kde.plasma.desktop/contents/layout.js
// on the live image to show the Installer icon on the desktop
//
// might be nicer to use icon plasmoid but I can't work out
// how to set the geometory of it from this script or to translate its caption
//
// jriddell 2014-10-10, GNU GPL 2+

loadTemplate("org.kde.plasma.desktop.defaultPanel")

for (var i = 0; i < screenCount; ++i) {
    var id = createActivity("Desktop");
    var desktopsArray = desktopsForActivity(id);
    print(desktopsArray.length);
    for( var j = 0; j < desktopsArray.length; j++) {
        desktopsArray[j].wallpaperPlugin = 'org.kde.image';
        var clock = desktopsArray[j].addWidget("org.kde.plasma.folder");
    }
}
